==> shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17.tar.gz: shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17/shinkensolutions/common_ui/htdocs/js/shinken-test-auto/property/shinken-auto-test-tools-property-single-select.js <==
SHINKEN.TOOLS.TEST_AUTO_PROPERTY_SINGLE_SELECT = (function ( self ) {
    self.DOM                       = {};
    self.TEST                      = {};
    self.ACTION                    = {};
    //********************************************  GET DOM ELEMENT   ****************************************//
    self.DOM.mainSelector          = function ( property_name, selector_only ) {
        var _to_return = SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.line( property_name ).querySelector( '.shinken-select-container[data-name="' + PROPERTY.CONST.SELECTOR.MAIN + '"]' );
        if ( selector_only ) {
            _to_return = _to_return.querySelector( ".shinken-select-selector" );
        }
        return _to_return;
    };
    //********************************************  TEST   **************************************************//
    self.TEST.visibleOptions       = function ( timeout, property_name, number_expected ) {
        setTimeout( function () {
            var _number_visible = 0;
            var _options        = self.DOM.mainSelector( property_name ).querySelectorAll( ".shinken-option" );
            for ( var i = 0, _size_i = _options.length; i < _size_i; i++ ) {
                if ( DOM.Service.isVisible( _options[ i ] ) ) {
                    _number_visible++;
                }
            }
            SHINKEN.TOOLS.TEST_AUTO.___isEqualsTo( _number_visible, number_expected, 'options of ' + property_name );
        }, timeout );
        return 10;
    };
    self.TEST.isState              = function ( timeout, property_name, state, value_to_set ) {
        SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.isState( timeout, property_name, state );
        setTimeout( function () {
            switch ( state ) {
                case PROPERTY.CONST.STATE_PROPERTY.INHERITANCE:
                    value_to_set = "Par défaut [Aucun]";
                    switch ( property_name ) {
                        case PROPERTY.CONST.NAME.CHECK_PERIOD:
                        case PROPERTY.CONST.NAME.NOTIFICATION_PERIOD:
                            value_to_set = "Par défaut [Toujours]";
                            break;
                    }
                    break;
            }
            switch ( value_to_set ) {
                case PROPERTY.CONST.CUSTOM_SELECT.NONE:
                    value_to_set = "Aucun";
                    switch ( property_name ) {
                        case PROPERTY.CONST.NAME.CHECK_PERIOD:
                        case PROPERTY.CONST.NAME.NOTIFICATION_PERIOD:
                            value_to_set = "Toujours";
                            break;
                    }
                    break;
            }
            var _dom_selector_title = SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.selector( property_name, PROPERTY.CONST.SELECTOR.MAIN, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.SELECTOR_LABEL );
            SHINKEN.TOOLS.TEST_AUTO.__isInnerTextEqualTo( _dom_selector_title, value_to_set, "dom_selector_label" );
        }, timeout );
        return 10;
    };
    self.TEST.validUserInteraction = function ( timeout, property_name ) {
        if ( __version_shinken === "V02.07.06" ){
            return 0
        }
        var _to_return        = 0;
        var _dom_list_select  = SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.selector( property_name, PROPERTY.CONST.SELECTOR.MAIN, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.LIST_SELECT );
        var _dom_filter_input = SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.selector( property_name, PROPERTY.CONST.SELECTOR.MAIN, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.FILTER_INPUT );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( timeout + _to_return, property_name, "" );
        _to_return += self.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.INHERITANCE );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( timeout + _to_return, _dom_list_select, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.LIST_SELECT );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.click( timeout + _to_return, self.DOM.mainSelector( property_name, true ) );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( timeout + _to_return, _dom_list_select, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.LIST_SELECT );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( timeout + _to_return, _dom_filter_input, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.FILTER_INPUT );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.hasFocus( timeout + _to_return, _dom_filter_input, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.FILTER_INPUT );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.setValue( timeout + _to_return, _dom_filter_input, "test_auto_valid" );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.dispatchEvent( timeout + _to_return, _dom_filter_input, SHINKEN.TOOLS.TEST_AUTO_KEY_EVENT.getDownEvent(), 3 );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.dispatchEvent( timeout + _to_return, _dom_filter_input, SHINKEN.TOOLS.TEST_AUTO_KEY_EVENT.getEnterEvent() );
        //SHOULD HAVE test_auto_valid SELECTED
        _to_return += self.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.USER_SET, "test_auto_valid" );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( timeout + _to_return, property_name, "test_auto_disabled" );
        _to_return += self.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.USER_SET, "test_auto_disabled" );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( timeout + _to_return, property_name, PROPERTY.CONST.CUSTOM_SELECT.NONE );
        _to_return += self.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.USER_SET, PROPERTY.CONST.CUSTOM_SELECT.NONE );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( timeout + _to_return, property_name, "" );
        _to_return += self.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.INHERITANCE );
        
        return _to_return;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_SINGLE_SELECT || {} );

==> shinken-enterprise_V02.08.01.02_ALL-LANG_Windows-poller-only_FULL_2023-04-05.tar.gz: shinken-enterprise_V02.08.01.02_ALL-LANG_Windows-poller-only_FULL_2023-04-05/shinkensolutions/common_ui/htdocs/js/shinken-test-auto/property/shinken-auto-test-tools-property-single-select.js <==
SHINKEN.TOOLS.TEST_AUTO_PROPERTY_SINGLE_SELECT = (function ( self ) {
    self.DOM                       = {};
    self.TEST                      = {};
    self.ACTION                    = {};
    //********************************************  GET DOM ELEMENT   ****************************************//
    self.DOM.mainSelector          = function ( property_name, selector_only ) {
        var _to_return = SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.line( property_name ).querySelector( '.shinken-select-container[data-name="' + PROPERTY.CONST.SELECTOR.MAIN + '"]' );
        if ( selector_only ) {
            _to_return = _to_return.querySelector( ".shinken-select-selector" );
        }
        return _to_return;
    };
    //********************************************  TEST   **************************************************//
    self.TEST.visibleOptions       = function ( timeout, property_name, number_expected ) {
        setTimeout( function () {
            var _number_visible = 0;
            var _options        = self.DOM.mainSelector( property_name ).querySelectorAll( ".shinken-option" );
            for ( var i = 0, _size_i = _options.length; i < _size_i; i++ ) {
                if ( DOM.Service.isVisible( _options[ i ] ) ) {
                    _number_visible++;
                }
            }
            SHINKEN.TOOLS.TEST_AUTO.___isEqualsTo( _number_visible, number_expected, 'options of ' + property_name );
        }, timeout );
        return 10;
    };
    self.TEST.isState              = function ( timeout, property_name, state, value_to_set ) {
        SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.isState( timeout, property_name, state );
        setTimeout( function () {
            switch ( state ) {
                case PROPERTY.CONST.STATE_PROPERTY.INHERITANCE:
                    value_to_set = "Par défaut [Aucun]";
                    switch ( property_name ) {
                        case PROPERTY.CONST.NAME.CHECK_PERIOD:
                        case PROPERTY.CONST.NAME.NOTIFICATION_PERIOD:
                            value_to_set = "Par défaut [Toujours]";
                            break;
                    }
                    break;
            }
            switch ( value_to_set ) {
                case PROPERTY.CONST.CUSTOM_SELECT.NONE:
                    value_to_set = "Aucun";
                    switch ( property_name ) {
                        case PROPERTY.CONST.NAME.CHECK_PERIOD:
                        case PROPERTY.CONST.NAME.NOTIFICATION_PERIOD:
                            value_to_set = "Toujours";
                            break;
                    }
                    break;
            }
            var _dom_selector_title = SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.selector( property_name, PROPERTY.CONST.SELECTOR.MAIN, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.SELECTOR_LABEL );
            SHINKEN.TOOLS.TEST_AUTO.__isInnerTextEqualTo( _dom_selector_title, value_to_set, "dom_selector_label" );
        }, timeout );
        return 10;
    };
    self.TEST.validUserInteraction = function ( timeout, property_name ) {
        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA ){
            return 0
        }
        var _to_return        = 0;
        var _dom_list_select  = SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.selector( property_name, PROPERTY.CONST.SELECTOR.MAIN, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.LIST_SELECT );
        var _dom_filter_input = SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.selector( property_name, PROPERTY.CONST.SELECTOR.MAIN, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.FILTER_INPUT );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( timeout + _to_return, property_name, "" );
        _to_return += self.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.INHERITANCE );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( timeout + _to_return, _dom_list_select, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.LIST_SELECT );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.click( timeout + _to_return, self.DOM.mainSelector( property_name, true ) );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( timeout + _to_return, _dom_list_select, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.LIST_SELECT );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( timeout + _to_return, _dom_filter_input, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.FILTER_INPUT );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.hasFocus( timeout + _to_return, _dom_filter_input, SHINKEN.TOOLS.TEST_AUTO_PROPERTY.CONST.UNDER_SELECTOR.FILTER_INPUT );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.setValue( timeout + _to_return, _dom_filter_input, "test_auto_valid" );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.dispatchEvent( timeout + _to_return, _dom_filter_input, SHINKEN.TOOLS.TEST_AUTO_KEY_EVENT.getDownEvent(), 3 );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.dispatchEvent( timeout + _to_return, _dom_filter_input, SHINKEN.TOOLS.TEST_AUTO_KEY_EVENT.getEnterEvent() );
        //SHOULD HAVE test_auto_valid SELECTED
        _to_return += self.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.USER_SET, "test_auto_valid" );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( timeout + _to_return, property_name, "test_auto_disabled" );
        _to_return += self.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.USER_SET, "test_auto_disabled" );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( timeout + _to_return, property_name, PROPERTY.CONST.CUSTOM_SELECT.NONE );
        _to_return += self.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.USER_SET, PROPERTY.CONST.CUSTOM_SELECT.NONE );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( timeout + _to_return, property_name, "" );
        _to_return += self.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.INHERITANCE );
        
        return _to_return;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_SINGLE_SELECT || {} );
